﻿-- ********************************************************************************
-- Broker Statistics
-- A Data Broker display for combat statistics.
-- By: Shenton
--
-- IconsFrame.lua
-- Icons selection frame.
-- ********************************************************************************

local A = _G["DataBrokerStatisticsGlobal"];

--- Init the icon selection frame and update when scrolling (Blizzard guild bank name/icon selection frame)
function A:PopupScrollUpdate()
	local icons, icon, button, index, texture;
	local popupOffset = FauxScrollFrame_GetOffset(BrokerStatisticsPopupFrameScrollFrame);

    if ( not BrokerStatisticsPopupFrame.iconList ) then
        icons = GetNumMacroIcons();
        TextureFunc = GetMacroIconInfo;
    else
        icons = GetNumMacroItemIcons();
        TextureFunc = GetMacroItemIconInfo;
    end

	for i=1,16 do
		icon = _G["BrokerStatisticsPopupFrameButton"..i.."Icon"];
		button = _G["BrokerStatisticsPopupFrameButton"..i];
		index = (popupOffset * 4) + i;
		texture = TextureFunc(index);

		if ( index <= icons ) then
			icon:SetTexture(texture);
			button:Show();
		else
			icon:SetTexture("");
			button:Hide();
		end

		if ( BrokerStatisticsPopupFrame.selectedIcon ) then
			if ( index == BrokerStatisticsPopupFrame.selectedIcon ) then
				button:SetChecked(1);
			else
				button:SetChecked(nil);
			end
		elseif ( BrokerStatisticsPopupFrame.currentTexture == texture ) then
			button:SetChecked(1);
			BrokerStatisticsPopupFrame.selectedIcon = index;
		else
			button:SetChecked(nil);
		end
	end

	if ( not BrokerStatisticsPopupFrame.selectedIcon ) then
		for i=1, icons do
			texture = GetMacroItemIconInfo(i);

			if ( BrokerStatisticsPopupFrame.currentTexture == texture ) then
				BrokerStatisticsPopupFrame.selectedIcon = i;
				break;
			end
		end
	end

	FauxScrollFrame_Update(BrokerStatisticsPopupFrameScrollFrame, ceil(icons / 4) , 4, 36);
end

--- When an icon is clicked
function A:PopupScrollButtonClick(self)
	local offset = FauxScrollFrame_GetOffset(BrokerStatisticsPopupFrameScrollFrame);
	local index = (offset * 4) + self:GetID();
	BrokerStatisticsPopupFrame.selectedIcon = index;
	A:PopupScrollUpdate();
end

-- Frame
function A:IconsFrame()
    local f = CreateFrame("Frame", "BrokerStatisticsPopupFrame", UIParent);
    f:SetClampedToScreen(1);
    f:SetFrameStrata("TOOLTIP");
    f:Hide();
    f:SetSize(253, 320);

    -- Textures
    f.topLeft = f:CreateTexture();
    f.topLeft:SetTexture("Interface\\MacroFrame\\MacroPopup-TopLeft");
    f.topLeft:SetSize(189, 256);
    f.topLeft:SetPoint("TOPLEFT", f);
    f.topLeft:SetDrawLayer("BACKGROUND");

    f.topleft = f:CreateTexture();
    f.topleft:SetTexture("Interface\\MacroFrame\\MacroPopup-TopRight");
    f.topleft:SetSize(64, 256);
    f.topleft:SetPoint("TOPRIGHT", f);
    f.topleft:SetDrawLayer("BACKGROUND");

    f.topleft = f:CreateTexture();
    f.topleft:SetTexture("Interface\\MacroFrame\\MacroPopup-BotLeft");
    f.topleft:SetSize(189, 64);
    f.topleft:SetPoint("BOTTOMLEFT", f);
    f.topleft:SetDrawLayer("BACKGROUND");

    f.topleft = f:CreateTexture();
    f.topleft:SetTexture("Interface\\MacroFrame\\MacroPopup-BotRight");
    f.topleft:SetSize(64, 64);
    f.topleft:SetPoint("BOTTOMRIGHT", f);
    f.topleft:SetDrawLayer("BACKGROUND");

    -- Text
    f.text = f:CreateFontString("BrokerStatisticsPopupFrameText");
    f.text:SetFontObject(SystemFont_Med1);
    f.text:SetText(A.L["Choose an icon from the list."]);
    f.text:SetPoint("TOPLEFT", f, 24, -30);

    -- Scroll
    f.scroll = CreateFrame("ScrollFrame", "BrokerStatisticsPopupFrameScrollFrame", f, "ListScrollFrameTemplate");
    f.scroll:SetSize(296, 195);
    f.scroll:SetPoint("TOPRIGHT", f, "TOPRIGHT", -59, -66);
    f.scroll:SetScript("OnVerticalScroll", function(self, offset)
        FauxScrollFrame_OnVerticalScroll(self, offset, 36, A.PopupScrollUpdate);
    end);

    -- Icons buttons
    f.button1 = CreateFrame("CheckButton", "BrokerStatisticsPopupFrameButton1", f, "PopupButtonTemplate");
    f.button1:SetID(1);
    f.button1:SetPoint("TOPLEFT", f, "TOPLEFT", 16, -86);
    f.button1:SetScript("OnClick", function(self) A:PopupScrollButtonClick(self); end);

    local button, row = 2, 1;
    while ( button <= 16 ) do
        if ( row == 4 ) then
            f["button"..button] = CreateFrame("CheckButton", "BrokerStatisticsPopupFrameButton"..button, _G["BrokerStatisticsPopupFrameButton"..button - 4], "PopupButtonTemplate");
            f["button"..button]:SetID(button);
            f["button"..button]:SetPoint("TOPLEFT", _G["BrokerStatisticsPopupFrameButton"..button - 4], "BOTTOMLEFT", 0, -8);
            f["button"..button]:SetScript("OnClick", function(self) A:PopupScrollButtonClick(self); end);
            row = 1;
        else
            f["button"..button] = CreateFrame("CheckButton", "BrokerStatisticsPopupFrameButton"..button, _G["BrokerStatisticsPopupFrameButton"..button - 1], "PopupButtonTemplate");
            f["button"..button]:SetID(button);
            f["button"..button]:SetPoint("LEFT", _G["BrokerStatisticsPopupFrameButton"..button - 1], "RIGHT", 10, 0);
            f["button"..button]:SetScript("OnClick", function(self) A:PopupScrollButtonClick(self); end);
            row = row + 1;
        end

        button = button + 1;
    end

    -- Cancel button
    f.cancelButton = CreateFrame("Button", "BrokerStatisticsPopupFrameButtonCancel", f, "UIPanelButtonTemplate");
    f.cancelButton:SetSize(69, 22);
    f.cancelButton:SetText(A.L["Cancel"]);
    f.cancelButton:SetScript("OnClick", function()
        BrokerStatisticsPopupFrame:Hide();
        BrokerStatisticsPopupFrame.ldbObject = nil;
        BrokerStatisticsPopupFrame.selectedIcon = nil;
        BrokerStatisticsPopupFrame.iconList = nil
    end);
    f.cancelButton:SetPoint("BOTTOMRIGHT", f, "BOTTOMRIGHT", -34, 34);

    -- Accept button
    f.acceptButton = CreateFrame("Button", "BrokerStatisticsPopupFrameButtonAccept", BrokerStatisticsPopupFrameButtonCancel, "UIPanelButtonTemplate");
    f.acceptButton:SetSize(69, 22);
    f.acceptButton:SetText(A.L["Accept"]);
    f.acceptButton:SetScript("OnClick", function()
        if ( not BrokerStatisticsPopupFrame.selectedIcon ) then
            A:Message(A.L["No icon selected."], 1, 1);
        else
            local texture;

            BrokerStatisticsPopupFrame:Hide();

            if ( not BrokerStatisticsPopupFrame.iconList ) then
                texture = GetMacroIconInfo(BrokerStatisticsPopupFrame.selectedIcon);
            else
                texture = GetMacroItemIconInfo(BrokerStatisticsPopupFrame.selectedIcon);
            end

            BrokerStatisticsPopupFrame.dbEdit.icon = texture;
            if ( BrokerStatisticsPopupFrame.ldbObject ) then
                BrokerStatisticsPopupFrame.ldbObject.icon = texture;
            end

            BrokerStatisticsPopupFrame.dbEdit = nil;
            BrokerStatisticsPopupFrame.ldbObject = nil;
            BrokerStatisticsPopupFrame.selectedIcon = nil;
            BrokerStatisticsPopupFrame.iconList = nil;

            A:RefreshConfig();
        end
    end);
    f.acceptButton:SetPoint("RIGHT", BrokerStatisticsPopupFrameButtonCancel, "LEFT", -2, 0);

    -- Default button
    f.acceptButton = CreateFrame("Button", "BrokerStatisticsPopupFrameButtonDefault", BrokerStatisticsPopupFrameButtonAccept, "UIPanelButtonTemplate");
    f.acceptButton:SetSize(69, 22);
    f.acceptButton:SetText(A.L["Default"]);
    f.acceptButton:SetScript("OnClick", function()
        BrokerStatisticsPopupFrame:Hide();

        BrokerStatisticsPopupFrame.dbEdit.icon = A.defaultLdbIcon;
        if ( BrokerStatisticsPopupFrame.ldbObject ) then
            BrokerStatisticsPopupFrame.ldbObject.icon = A.defaultLdbIcon;
        end

        BrokerStatisticsPopupFrame.dbEdit = nil;
        BrokerStatisticsPopupFrame.ldbObject = nil;
        BrokerStatisticsPopupFrame.selectedIcon = nil;
        BrokerStatisticsPopupFrame.iconList = nil;

        A:RefreshConfig();
    end);
    f.acceptButton:SetPoint("RIGHT", BrokerStatisticsPopupFrameButtonAccept, "LEFT", -2, 0);
end
